@@ -3,6 +3,9 @@ globalVariables(
         "outside",".cluster","centers","glance","k_means","prop_of_total","tot.withinss",
         "total_records","PC","var_explained","cum_var_pct","ou_threshold",
         "iterations","number_of_clusters","within_cluster_sum_of_squares","wss",
-        "predict","predicted_cluster","printer","rand_id"
+        "predict","predicted_cluster","printer","rand_id",
+        "distribution","dist_data","density","density_data","density_obj","df",
+        "dist_supported","stats_func","value","x","y","sd","key","fct_rev",
+        "component","terms","pos_neg","abs_value","Positive?"
     )
 )
